@@ -1,5 +1,5 @@
 /********************************************************************************
- *  Copyright (C) 2015-2017 by Mihai Moldovan <ionic@ionic.de> +49 721 14595728 *
+ *  Copyright (C) 2015-2020 by Mihai Moldovan <ionic@ionic.de> +49 721 14595728 *
  *                                                                              *
  *  This program is free software; you can redistribute it and/or modify        *
  *  it under the terms of the GNU General Public License as published by        *
@@ -110,6 +110,12 @@ help::params_t help::build_params () {
   ADD_OPT ("--debug", QT_TRANSLATE_NOOP ("Help", "Enables extensive debug output to the console." NEWLINE
                                          "On Windows, also enables PulseAudio logging to a file under \".x2go/pulse\" & cygwin sshd logging to a file under \".x2go/sshLogs\" directory, both under the USERPROFILE directory." NEWLINE
                                          "The logs are not deleted when X2Go Client terminates."));
+  ADD_OPT ("--libssh-debug", QT_TRANSLATE_NOOP ("Help", "Instructs libssh to print out extensive debug output to the console." NEWLINE
+                                                "This will only have an effect if libssh is being used. It tends to generate a lot of output." NEWLINE
+                                                "WARNING: Enabling this option could reveal sensitive information about client and server configuration, and, if libssh has been compiled with password debugging, user credentials. Do not publish log files created with this option."));
+  ADD_OPT ("--libssh-packetlog", QT_TRANSLATE_NOOP ("Help", "Instructs libssh to print out all network packets sent and received, including their contents." NEWLINE
+                                                    "This will only have an effect if libssh is being used. It tends to generate huge amounts of output." NEWLINE
+                                                    "WARNING: The same caveats as explained in the --libssh-debug option help text apply."));
   ADD_OPT ("--no-autoresume", QT_TRANSLATE_NOOP ("Help", "Do not resume sessions automatically."));
   ADD_OPT ("--no-menu", QT_TRANSLATE_NOOP ("Help", "Hides menu bar."));
   ADD_OPT ("--no-session-edit", QT_TRANSLATE_NOOP ("Help", "Disables session editing."));
@@ -167,6 +173,9 @@ help::params_t help::build_params () {
                                                              "If <num> is zero or a negative number, no limit is imposed." NEWLINE
                                                              "The limits for <num> are platform dependent. If the passed value is out of bounds, X2Go Client falls back to the default value."));
 #endif /* defined (Q_OS_WIN) */
+#if defined (Q_OS_UNIX)
+  ADD_OPT ("--bypass-cleanup-helper", QT_TRANSLATE_NOOP ("Help", "Disables X2Go Client's UNIX cleanup helper. This will prevent X2Go Client from terminating spawned processes after the main program terminates or crashes. Use with care and when in doubt, do not use this parameter at all."));
+#endif /* defined (Q_OS_UNIX) */
 
 # undef NEWLINE
 # undef ADD_OPT
