@@ -1,6 +1,6 @@
 /**************************************************************************
-*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
-*   o.shneyder@phoca-gmbh.de                                              *
+*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -44,6 +44,11 @@ HttpBrokerClient::HttpBrokerClient ( ONMainWindow* wnd, ConfigFile* cfg )
     config=cfg;
     mainWindow=wnd;
     sshConnection=0;
+    sessionsRequest=0l;
+    selSessRequest=0l;
+    chPassRequest=0l;
+    testConRequest=0l;
+    eventRequest=0l;
     QUrl lurl ( config->brokerurl );
     if(lurl.userName().length()>0)
         config->brokerUser=lurl.userName();
@@ -270,6 +275,7 @@ void HttpBrokerClient::slotSshUserAuthError(QString error)
     return;
 }
 
+
 void HttpBrokerClient::getUserSessions()
 {
     QString brokerUser=config->brokerUser;
@@ -290,7 +296,7 @@ void HttpBrokerClient::getUserSessions()
                              "password="<<QUrl::toPercentEncoding(config->brokerPass)<<"&"<<
                              "authid="<<nextAuthId;
 
-        x2goDebug << "sending request: "<< req.toUtf8();
+        x2goDebug << "sending request: "<< scramblePwd(req.toUtf8());
         QNetworkRequest request(QUrl(config->brokerurl));
         request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
         sessionsRequest=http->post (request, req.toUtf8() );
@@ -312,9 +318,9 @@ void HttpBrokerClient::getUserSessions()
     }
 }
 
-void HttpBrokerClient::selectUserSession(const QString& session)
+void HttpBrokerClient::selectUserSession(const QString& session, const QString& loginName)
 {
-    x2goDebug<<"Called selectUserSession for session "<<session<<".";
+    x2goDebug<<"Called selectUserSession for session "<<session<<", "<<"loginName "<<loginName;
     QString brokerUser=config->brokerUser;
     if(mainWindow->getUsePGPCard())
         brokerUser=mainWindow->getCardLogin();
@@ -328,7 +334,11 @@ void HttpBrokerClient::selectUserSession(const QString& session)
                              "user="<<QUrl::toPercentEncoding(brokerUser)<<"&"<<
                              "password="<<QUrl::toPercentEncoding(config->brokerPass)<<"&"<<
                              "authid="<<nextAuthId;
-        x2goDebug << "Sending request: "<< req.toUtf8();
+        if(loginName.length()>0)
+        {
+            QTextStream ( &req ) <<"&login="<<QUrl::toPercentEncoding(loginName);
+        }
+        x2goDebug << "sending request: "<< scramblePwd(req.toUtf8());
         QNetworkRequest request(QUrl(config->brokerurl));
         request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
         selSessRequest=http->post (request, req.toUtf8() );
@@ -336,17 +346,96 @@ void HttpBrokerClient::selectUserSession(const QString& session)
     }
     else
     {
-        if (nextAuthId.length() > 0) {
-            sshConnection->executeCommand ( config->sshBrokerBin+" --user "+ brokerUser +" --authid "+nextAuthId+ " --task selectsession --sid \""+session+"\"",
-                                            this,SLOT ( slotSelectSession(bool,QString,int)));
-        } else {
-            sshConnection->executeCommand ( config->sshBrokerBin+" --user "+ brokerUser +" --task selectsession --sid \""+session+"\"",
-                                            this,SLOT ( slotSelectSession(bool,QString,int)));
+        QString sshCmd=config->sshBrokerBin+" --user "+ brokerUser + " --task selectsession --sid \""+session+"\"";
+        if(nextAuthId.length() > 0)
+        {
+            sshCmd+=" --authid "+nextAuthId;
         }
+        if(loginName.length() > 0)
+        {
+            sshCmd+=" --login " + loginName;
+        }
+        sshConnection->executeCommand (sshCmd, this,SLOT ( slotSelectSession(bool,QString,int)));
     }
 
 }
 
+void HttpBrokerClient::sendEvent(const QString& ev, const QString& id, const QString& server, const QString& client,
+                                 const QString& login, const QString& cmd,
+                                 const QString& display, const QString& start, uint connectionTime)
+{
+    x2goDebug<<"Called sendEvent.";
+    QString brokerUser=config->brokerUser;
+    if(mainWindow->getUsePGPCard())
+        brokerUser=mainWindow->getCardLogin();
+
+    if(!sshBroker)
+    {
+        QString req;
+        QTextStream ( &req ) <<
+                             "task=clientevent&"<<
+                             "user="<<QUrl::toPercentEncoding(brokerUser)<<"&"<<
+                             "password="<<QUrl::toPercentEncoding(config->brokerPass)<<"&"<<
+                             "sid="<<id<<"&"<<
+                             "event="<<ev<<"&"<<
+                             "server="<<QUrl::toPercentEncoding(server)<<"&"<<
+                             "client="<<QUrl::toPercentEncoding(client)<<"&"<<
+                             "login="<<QUrl::toPercentEncoding(login)<<"&"<<
+                             "cmd="<<QUrl::toPercentEncoding(cmd)<<"&"<<
+                             "display="<<QUrl::toPercentEncoding(display)<<"&"<<
+                             "start="<<QUrl::toPercentEncoding(start)<<"&"<<
+                             "elapsed="<<QString::number(connectionTime)<<"&"<<
+                             "authid="<<nextAuthId;
+        x2goDebug << "sending request: "<< scramblePwd(req.toUtf8());
+        QNetworkRequest request(QUrl(config->brokerurl));
+        request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
+        eventRequest=http->post (request, req.toUtf8() );
+
+    }
+    else
+    {
+        if (nextAuthId.length() > 0) {
+            sshConnection->executeCommand ( config->sshBrokerBin+" --user "+ brokerUser +" --authid "+nextAuthId+
+            " --task clientevent --sid \""+id+"\" --event "+ev+" --server \""+server+"\" --client \""+client+"\" --login "+"\""+
+            login+"\" --cmd \""+cmd+"\" --display \""+display+"\" --start \""+start+"\" --elapsed "+QString::number(connectionTime),
+            this,SLOT ( slotEventSent(bool,QString,int)));
+        } else {
+            sshConnection->executeCommand ( config->sshBrokerBin+" --user "+ brokerUser +
+            " --task clientevent --sid \""+id+"\" --event "+ev+" --server \""+server+"\" --client \""+client+"\" --login "+"\""+
+            login+"\" --cmd \""+cmd+"\" --display \""+display+"\" --start \""+start+"\" --elapsed "+QString::number(connectionTime),
+            this,SLOT ( slotEventSent(bool,QString,int)));
+        }
+    }
+}
+
+
+void HttpBrokerClient::slotEventSent(bool success, QString answer, int)
+{
+    if(!success)
+    {
+        x2goDebug<<answer;
+        QMessageBox::critical(0,tr("Error"),answer);
+        emit fatalHttpError();
+        return;
+    }
+    if(!checkAccess(answer))
+        return;
+    x2goDebug<<"event sent:"<<answer;
+    if(answer.indexOf("SUSPEND")!=-1)
+    {
+        QString sid=answer.split("SUSPEND ")[1].simplified();
+        x2goDebug<<"broker asks to suspend "<<sid;
+        mainWindow->suspendFromBroker(sid);
+    }
+    if(answer.indexOf("TERMINATE")!=-1)
+    {
+        QString sid=answer.split("TERMINATE ")[1].simplified();
+        x2goDebug<<"broker asks to terminate "<<sid;
+        mainWindow->terminateFromBroker(sid);
+    }
+}
+
+
 void HttpBrokerClient::changePassword(QString newPass)
 {
     newBrokerPass=newPass;
@@ -363,7 +452,7 @@ void HttpBrokerClient::changePassword(QString newPass)
                              "user="<<QUrl::toPercentEncoding(brokerUser)<<"&"<<
                              "password="<<QUrl::toPercentEncoding(config->brokerPass)<<"&"<<
                              "authid="<<nextAuthId;
-        x2goDebug << "Sending request: "<< req.toUtf8();
+        x2goDebug << "sending request: "<< scramblePwd(req.toUtf8());
         QNetworkRequest request(QUrl(config->brokerurl));
         request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
         chPassRequest=http->post (request, req.toUtf8() );
@@ -388,7 +477,7 @@ void HttpBrokerClient::testConnection()
         QString req;
         QTextStream ( &req ) <<
                              "task=testcon";
-        x2goDebug << "Sending request: "<< req.toUtf8();
+        x2goDebug << "sending request: "<< scramblePwd(req.toUtf8());
         QNetworkRequest request(QUrl(config->brokerurl));
         request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
         testConRequest=http->post (request, req.toUtf8() );
@@ -405,6 +494,21 @@ void HttpBrokerClient::testConnection()
     }
 }
 
+void HttpBrokerClient::processClientConfig(const QString& raw_content)
+{
+    X2goSettings st(raw_content, QSettings::IniFormat);
+    mainWindow->config.brokerEvents=st.setting()->value("events",false).toBool();
+    mainWindow->config.brokerLiveEventsTimeout=st.setting()->value("liveevent",false).toUInt();
+    if(mainWindow->config.brokerEvents)
+    {
+        x2goDebug<<"sending client events to broker";
+        if(mainWindow->config.brokerLiveEventsTimeout)
+        {
+            x2goDebug<<"sending alive events to broker every "<<mainWindow->config.brokerLiveEventsTimeout<<" seconds";
+        }
+    }
+}
+
 
 void HttpBrokerClient::createIniFile(const QString& raw_content)
 {
@@ -420,6 +524,17 @@ void HttpBrokerClient::createIniFile(const QString& raw_content)
         cont=cont.split("END_USER_SESSIONS\n")[0];
     }
     mainWindow->config.iniFile=cont;
+    lines=content.split("START_CLIENT_CONFIG\n");
+    if (lines.count()>1)
+    {
+        cont=lines[1];
+        cont=cont.split("END_CLIENT_CONFIG\n")[0];
+        processClientConfig(cont);
+    }
+    else
+    {
+        x2goDebug<<"no client config from broker";
+    }
 }
 
 
@@ -517,6 +632,13 @@ void HttpBrokerClient::slotRequestFinished ( QNetworkReply*  reply )
     if(reply->error() != QNetworkReply::NoError)
     {
         x2goDebug<<"Broker HTTP request failed with error: "<<reply->errorString();
+        if(reply == eventRequest)
+        {
+            reply->deleteLater();
+            eventRequest=0l;
+            //do not exit, just return the function
+            return;
+        }
         QMessageBox::critical(0,tr("Error"),reply->errorString());
         emit fatalHttpError();
         return;
@@ -526,20 +648,29 @@ void HttpBrokerClient::slotRequestFinished ( QNetworkReply*  reply )
     x2goDebug<<"A http request returned. Result was: "<<answer;
     if (reply == testConRequest)
     {
+        testConRequest=0l;
         slotConnectionTest(true,answer,0);
     }
-    if (reply == sessionsRequest)
+    else if (reply == sessionsRequest)
     {
+        sessionsRequest=0l;
         slotListSessions(true, answer,0);
     }
-    if (reply == selSessRequest)
+    else if (reply == selSessRequest)
     {
+        selSessRequest=0l;
         slotSelectSession(true,answer,0);
     }
-    if (reply == chPassRequest)
+    else if (reply == chPassRequest)
     {
+        chPassRequest=0l;
         slotPassChanged(true,answer,0);
     }
+    else if (reply == eventRequest)
+    {
+        eventRequest=0l;
+        slotEventSent(true,answer,0);
+    }
 
     // We receive ownership of the reply object
     // and therefore need to handle deletion.
@@ -549,6 +680,7 @@ void HttpBrokerClient::slotRequestFinished ( QNetworkReply*  reply )
 void HttpBrokerClient::parseSession(QString sinfo)
 {
     config->sessiondata="";
+    suspendedSession.clear();
     x2goDebug<<"Starting parser.";
     QStringList lst=sinfo.split("SERVER:",QString::SkipEmptyParts);
     int keyStartPos=sinfo.indexOf("-----BEGIN DSA PRIVATE KEY-----");
@@ -573,11 +705,31 @@ void HttpBrokerClient::parseSession(QString sinfo)
     if (sinfo.indexOf("SESSION_INFO")!=-1)
     {
         QStringList lst=sinfo.split("SESSION_INFO:",QString::SkipEmptyParts);
-        config->sessiondata=lst[1];
-        x2goDebug<<"Session data: "<<config->sessiondata<<"\n";
+        //config->sessiondata=lst[1];
+        x2goDebug<<"Session data: "<<lst[1]<<"\n";
+        suspendedSession=lst[1].trimmed().split ( '\n', QString::SkipEmptyParts );
+        mainWindow->selectSession(suspendedSession);
+    }
+    else
+    {
+        emit sessionSelected();
     }
     x2goDebug<<"Parsing has finished.";
-    emit sessionSelected();
+}
+
+void HttpBrokerClient::resumeSession(const QString& id, const QString& server)
+{
+    x2goDebug<<"Resuming session with id:"<<id<<"on:"<<server;
+    foreach (QString sline, suspendedSession)
+    {
+        if(sline.indexOf(id)!=-1)
+        {
+            config->sessiondata=sline;
+            config->serverIp=server;
+            emit sessionSelected();
+            break;
+        }
+    }
 }
 
 
@@ -735,3 +887,27 @@ void HttpBrokerClient::slotSshIoErr(SshProcess* caller, QString error, QString l
     }
     createSshConnection();
 }
+
+QString HttpBrokerClient::scramblePwd(const QString& req)
+{
+    QString scrambled=req;
+    int startPos=scrambled.indexOf("password=");
+    if(startPos!=-1)
+    {
+        startPos+=9;
+        int endPos=scrambled.indexOf("&",startPos);
+        int plength;
+        if(endPos==-1)
+        {
+            plength=scrambled.length()-startPos;
+        }
+        else
+        {
+            plength=endPos-startPos;
+        }
+        scrambled.remove(startPos, plength);
+        // Hardcode a value of 8 here - the length of the string "password".
+        scrambled.insert(startPos, QString ('*').repeated (8));
+    }
+    return scrambled;
+}
