@@ -1,6 +1,6 @@
 /**************************************************************************
-*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
-*   o.shneyder@phoca-gmbh.de                                              *
+*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -41,10 +41,13 @@ class HttpBrokerClient: public QObject
 public:
     HttpBrokerClient ( ONMainWindow* wnd, ConfigFile* cfg );
     ~HttpBrokerClient();
-    void selectUserSession(const QString& session );
+    void selectUserSession(const QString& session, const QString& loginName);
     void changePassword(QString newPass);
     void testConnection();
     void closeSSHInteractionDialog();
+    void sendEvent(const QString& ev, const QString& id, const QString& server, const QString& client,
+                   const QString& login, const QString& cmd, const QString& display, const QString& start, uint connectionTime);
+    void resumeSession(const QString& id, const QString& server);
 private:
     QNetworkAccessManager* http;
     QNetworkRequest* netRequest;
@@ -53,6 +56,7 @@ private:
     QNetworkReply* selSessRequest;
     QNetworkReply* chPassRequest;
     QNetworkReply* testConRequest;
+    QNetworkReply* eventRequest;
     QString nextAuthId;
     QString newBrokerPass;
     ConfigFile* config;
@@ -60,11 +64,14 @@ private:
     QTime requestTime;
     bool sshBroker;
     SshMasterConnection* sshConnection;
+    QStringList suspendedSession;
 private:
     void createIniFile(const QString& raw_content);
+    void processClientConfig(const QString& raw_content);
     void parseSession(QString sInfo);
     void createSshConnection();
     bool checkAccess(QString answer);
+    QString scramblePwd(const QString& req);
 
 private slots:
     void slotRequestFinished ( QNetworkReply*  reply );
@@ -78,6 +85,7 @@ private slots:
     void slotListSessions ( bool success, QString answer, int pid);
     void slotSelectSession ( bool success, QString answer, int pid);
     void slotPassChanged ( bool success, QString answer, int pid);
+    void slotEventSent ( bool success, QString answer, int pid);
     void slotConnectionTest( bool success, QString answer, int pid);
     void slotSshIoErr(SshProcess* caller, QString error, QString lastSessionError);
 
