@@ -1,6 +1,6 @@
 /**************************************************************************
-*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
-*   o.shneyder@phoca-gmbh.de                                              *
+*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -52,7 +52,6 @@
 /**
 @author Oleksandr Shneyder
 */
-
 class QToolButton;
 class QTemporaryFile;
 class QLineEdit;
@@ -147,10 +146,12 @@ struct x2goSession
     QString grPort;
     QString sndPort;
     QString fsPort;
+    QString brokerUser;
+    uint connectedSince;
     bool published;
     int colorDepth;
     bool fullscreen;
-    enum {DESKTOP,ROOTLESS,SHADOW} sessionType;
+    enum {DESKTOP,ROOTLESS,SHADOW, KDRIVE} sessionType;
     QString command;
     void operator = ( const x2goSession& s );
 };
@@ -169,6 +170,8 @@ struct ConfigFile
     bool brokerAutologin;
     bool brokerAutologoff;
     bool brokerKrbLogin;
+    bool brokerEvents; //Send events to broker and get control commands
+    uint brokerLiveEventsTimeout; //(seconds)How often send alive events, 0 - do not send
     QString brokerSshKey;
     QString brokerCaCertFile;
     QString iniFile;
@@ -300,7 +303,18 @@ public:
         UNKNOWN_KEY_TYPE
     };
 
+    enum client_events {
+        CONNECTING,
+        CONNECTED,
+        SUSPENDING,
+        TERMINATING,
+        FINISHED,
+        ALIVE
+    };
+
     static bool debugging;
+    static bool libssh_debugging;
+    static bool libssh_packetlog;
 
     static bool portable;
     ONMainWindow ( QWidget *parent = 0 );
@@ -311,8 +325,10 @@ public:
     static bool isServerRunning ( int port );
     void startNewSession();
     void suspendSession ( QString sessId );
+    void suspendBrokerSession ( const QString& sessId, const QString& host );
     bool termSession ( QString sessId,
                        bool warn=true );
+    void termBrokerSession ( const QString& sessId, const QString& host );
     InteractionDialog* getInteractionDialog()
     {
       return interDlg;
@@ -711,10 +727,10 @@ private:
     QString currentKey;
     QTimer *exportTimer;
     QTimer *extTimer;
-    QTimer *agentCheckTimer;
     QTimer *spoolTimer;
     QTimer *proxyWinTimer;
     QTimer *xineramaTimer;
+    QTimer *brokerAliveTimer;
     short xinSizeInc;
     QRect lastDisplayGeometry;
     QList <QRect> xineramaScreens;
@@ -859,6 +875,8 @@ private:
     int lastUid;
     bool cardReady;
     HttpBrokerClient* broker;
+    client_events lastBrokerEvent;
+    QString lastBrokerEventSession;
 
 
 #if defined ( Q_OS_WIN) //&& defined (CFGCLIENT )
@@ -900,6 +918,19 @@ private:
     bool trayMaxDiscon;
     bool trayAutoHidden;
 
+    //server connection type
+    // DEFAULT - start X2GO session
+    // SUSPEND - open connection to suspend broker session
+    // TERMINATE - open connection to terminate broker session
+    typedef enum {DEFAULT, SUSPEND, TERMINATE} CONTYPE;
+
+    CONTYPE connectionType;
+    QString suspendTerminateHostFromBroker;
+    QString suspendTerminateSessionFromBroker;
+
+    void sendEventToBroker(client_events ev);
+    void suspendFromBroker(const QString& sid);
+    void terminateFromBroker(const QString& sid);
     QString findSshKeyForServer(QString user, QString server, QString port);
     void loadSettings();
     void showPass ( UserButton* user );
@@ -912,7 +943,7 @@ private:
     QString getKdeIconsPath();
     QString findTheme ( QString theme );
     bool initLdapSession ( bool showBox=true );
-    bool startSession ( const QString& id );
+    bool startSession ( const QString& id, CONTYPE conType=DEFAULT);
     x2goSession getSessionFromString ( const QString& string );
     void resumeSession ( const x2goSession& s );
     void selectSession ( QStringList& sessions );
@@ -1040,6 +1071,7 @@ public slots:
     void slotEnableBrokerLogoutButton ();
 
 private slots:
+    void slotSendBrokerAlive();
     void slotShowPAMSGDialog(bool error, const QString& main_text, const QString& info_text, bool modal);
     void slotSnameChanged ( const QString& );
     void slotSelectedFromList ( SessionButton* session );
