@@ -1,6 +1,6 @@
 /**************************************************************************
-*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
-*   o.shneyder@phoca-gmbh.de                                              *
+*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -23,6 +23,7 @@
 #include "x2gosettings.h"
 #include "x2gologdebug.h"
 #include <QDir>
+#include <QButtonGroup>
 #ifdef Q_OS_WIN
 #include "wapi.h"
 #endif
