@@ -1,6 +1,6 @@
 /**************************************************************************
-*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
-*   o.shneyder@phoca-gmbh.de                                              *
+*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -237,7 +237,7 @@ void SessionExplorer::slotCreateDesktopIcon ( SessionButton* bt )
         "link.WorkingDirectory = \""<<workDir<<"\"\n"<<
         "link.Save\n";
     file.close();
-    system ( scrname.toAscii() );
+    system ( scrname.toLatin1() );
     QFile::remove ( scrname );
 #endif
 }
