@@ -1,6 +1,6 @@
 /**************************************************************************
-*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
-*   o.shneyder@phoca-gmbh.de                                              *
+*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -207,6 +207,7 @@ SessionWidget::SessionWidget ( bool newSession, QString id, ONMainWindow * mw,
     QHBoxLayout* cmdLay=new QHBoxLayout ();
     cmdLay->addWidget ( new QLabel ( tr ( "Session type:" ),this ) );
 #endif
+    cbKdrive=new QCheckBox(tr("Run in X2GoKDrive (experimental)"));
     sessBox=new QComboBox ( deskSess );
     cmd=new QLineEdit ( deskSess );
     cmdCombo=new QComboBox ( deskSess );
@@ -224,18 +225,19 @@ SessionWidget::SessionWidget ( bool newSession, QString id, ONMainWindow * mw,
     sessBox->addItem ( "ICEWM" );
     sessBox->addItem ( tr ( "Connect to Windows Terminal Server" ) );
     sessBox->addItem ( tr ( "XDMCP" ) );
-    sessBox->addItem ( tr ( "Connect to local desktop" ) );
+    sessBox->addItem ( tr ( "X2Go/X11 Desktop Sharing" ) );
     sessBox->addItem ( tr ( "Custom desktop" ) );
     sessBox->addItem ( tr ( "Single application" ) );
     sessBox->addItem ( tr ( "Published applications" ) );
-    cmdLay->addWidget ( sessBox,0,1,Qt::AlignLeft );
+    cmdLay->addWidget ( cbKdrive,0,1,Qt::AlignLeft );
+    cmdLay->addWidget ( sessBox,1,1,Qt::AlignLeft );
     leCmdIp=new QLabel ( tr ( "Command:" ),deskSess );
     pbAdvanced=new QPushButton ( tr ( "Advanced options..." ),deskSess );
-    cmdLay->addWidget ( leCmdIp,0,2 );
+    cmdLay->addWidget ( leCmdIp,1,2 );
     cmdLay->setColumnStretch(6,1);
-    cmdLay->addWidget ( cmd ,0,3);
-    cmdLay->addWidget ( cmdCombo,0,4 );
-    cmdLay->addWidget ( pbAdvanced ,0,5);
+    cmdLay->addWidget ( cmd ,1,3);
+    cmdLay->addWidget ( cmdCombo,1,4 );
+    cmdLay->addWidget ( pbAdvanced ,1,5);
     cmdCombo->setSizePolicy ( QSizePolicy::Expanding,
                               QSizePolicy::Preferred );
     cmdCombo->hide();
@@ -254,7 +256,7 @@ SessionWidget::SessionWidget ( bool newSession, QString id, ONMainWindow * mw,
     sessLay->addWidget ( deskSess );
 #ifdef Q_OS_LINUX
     cbDirectRDP=new QCheckBox(tr("Direct RDP connection"), deskSess);
-    cmdLay->addWidget(cbDirectRDP,1,0,1,6);
+    cmdLay->addWidget(cbDirectRDP,2,0,1,6);
     cbDirectRDP->hide();
     connect(cbDirectRDP,SIGNAL(clicked()), this, SLOT(slot_rdpDirectClicked()));
 #endif
@@ -666,13 +668,6 @@ void SessionWidget::readConfig()
                                     false
                                 ).toBool() );
 
-    if(proxyHost->text().indexOf(":")!=-1)
-    {
-        QStringList parts=proxyHost->text().split(":");
-        proxyHost->setText(parts[0]);
-        proxyPort->setValue(parts[1].toInt());
-    }
-
 
     QTimer::singleShot(1, this,SLOT(slot_proxySameLogin()));
     QTimer::singleShot(2, this,SLOT(slot_proxyType()));
@@ -799,6 +794,9 @@ void SessionWidget::readConfig()
         sessName->selectAll();
         sessName->setFocus();
     }
+
+    cbKdrive->setChecked(st.setting()->value (sessionId+"/kdrive", false).toBool() );
+
 #ifdef Q_OS_LINUX
     slot_rdpDirectClicked();
 #endif
@@ -811,6 +809,7 @@ void SessionWidget::setDefaults()
     sessBox->setCurrentIndex ( KDE );
     cmdCombo->clear();
     cmdCombo->addItem ( "" );
+    cbKdrive->setChecked(false);
     cmdCombo->addItems ( mainWindow->transApplicationsNames() );
     cbAutoLogin->setChecked(false);
     cbKrbLogin->setChecked(false);
@@ -883,6 +882,8 @@ void SessionWidget::saveSettings()
     st.setting()->setValue(sessionId+"/directrdp",( QVariant ) cbDirectRDP->isChecked());
     st.setting()->setValue(sessionId+"/directxdmcp",( QVariant ) cbDirectRDP->isChecked());
 #endif
+
+    st.setting()->setValue(sessionId+"/kdrive",( QVariant ) cbKdrive->isChecked());
     QString command;
     bool rootless=false;
     bool published=false;
