@@ -1,6 +1,6 @@
 /**************************************************************************
-*   Copyright (C) 2005-2017 by Oleksandr Shneyder                         *
-*   o.shneyder@phoca-gmbh.de                                              *
+*   Copyright (C) 2005-2020 by Oleksandr Shneyder                         *
+*                              <o.shneyder@phoca-gmbh.de>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -24,6 +24,7 @@
 #ifdef Q_OS_WIN
 #include <winsock2.h>
 #include <windows.h>
+#include <winerror.h>
 #include <sddl.h>
 #include "wapi.h"
 #include "x2gologdebug.h"
